@@ -9,6 +9,8 @@
  * Josef Weidendorfer, 28.8.97
 */
 
+#include <stdio.h>
+
 #include <qdatetime.h>
 #include <qstrlist.h>
 
@@ -16,7 +18,7 @@
 #include <krandomsequence.h>
 
 #include "Board.h"
-#include <stdio.h>
+#include "EvalScheme.h"
 
 // #define MYTRACE 1
 
@@ -84,26 +86,27 @@ int Board::order[]={
 	  64,75,86,97,108,107,106,105,104,92,80,68,56,45,34,23,12,
 	  13,14,15,16,28,40,52 };
 
-/* ratings for fields are calculated out of these values
- * (see setFieldValues)
- */
-int Board::ringValue[] = { 45, 35, 25, 10, 0 };
-int Board::ringDiff[]  = {  0, 10, 10,  8, 5 };
+/* See EvalScheme.{h|cpp}
+ *
+  // Ratings for fields are calculated out of these values
+  // (see setFieldValues)  
+  int Board::ringValue[] = { 45, 35, 25, 10, 0 };
+  int Board::ringDiff[]  = {  0, 10, 10,  8, 5 };
+  
+  // Value added to board rating according to the difference of 
+  // stones in game of player1 and player2
+  int Board::stoneValue[]= { 0,-800,-1800,-3000,-4400,-6000 };
+  
+  // Default Values for moves values (see Move.h)
+  int Board::moveValue[]= { 40,30,30, 15,14,13, 5,5,5, 2,2,2, 1 };
+  
+  // Default Values for inARow values (see Move.h)
+  int Board::inARowValue[]= { 2, 5, 4, 3 };
+*/
 
 int Board::fieldValue[61];
-
-/* Value added to board rating according to the difference of 
- * stones in game of player1 and player2 */
-int Board::stoneValue[]= { 0,-800,-1800,-3000,-4400,-6000 };
-
 int Board::direction[]= { -11,1,12,11,-1,-12,-11,1 };
 
-/* Default Values for moves values (see Move.h) */
-int Board::moveValue[]= { 40,30,30, 15,14,13, 5,5,5, 2,2,2, 1 };
-
-/* Default Values for connect values (see Move.h) */
-int Board::connectValue[]= { 2, 5, 4, 3 };
-
 
 Board::Board()
 {
@@ -113,16 +116,31 @@ Board::Board()
   spyDepth = 0;
   debug = 0;
   realMaxDepth = 1;
+  _evalScheme = 0;
+}
+
+void Board::setEvalScheme(EvalScheme* scheme)
+{
+  if (!scheme)
+    scheme = new EvalScheme( QString("Default") );
+
+  _evalScheme = scheme;
   setFieldValues();
 }
 
 void Board::setFieldValues()
 {
+  if (!_evalScheme) return;
+
   int i, j = 0, k = 59;
+  int ringValue[5], ringDiff[5];
 
-  for(i=0;i<5;i++)
+  for(i=0;i<5;i++) {
+    ringDiff[i]  = _evalScheme->ringDiff(i);
+    ringValue[i] = _evalScheme->ringValue(i);
     if (ringDiff[i]<1) ringDiff[i]=1;
-
+  }
+  
   fieldValue[0] = ringValue[0];
   for(i=1;i<7;i++) 
     fieldValue[i] = ringValue[1] + ((j+=k) % ringDiff[1]);
@@ -134,89 +152,28 @@ void Board::setFieldValues()
     fieldValue[i] = ringValue[4] + ((j+=k) % ringDiff[4]);
 }
 
-void Board::readRating(KConfig *config)
-{
-  QStrList list;
-  QString tmp;
-
-  if (config->readListEntry("StoneValues", list)) {
-    stoneValue[0] = 0;
-    for(int i=1;i<6;i++)
-      stoneValue[i] = (tmp = list.at(i-1)).toInt();
-  }
-
-  if (config->readListEntry("MoveValues", list)) {
-    for(int i=0;i<Move::typeCount;i++)
-      moveValue[i] = (tmp = list.at(i)).toInt();
-  }
-
-  if (config->readListEntry("ConnectValues", list)) {
-    for(int i=0;i<ConnectCounter::connectCount;i++)
-      connectValue[i] = (tmp = list.at(i)).toInt();
-  }
-
-  if (config->readListEntry("RingValues", list)) {
-    for(int i=0;i<5;i++)
-      ringValue[i] = (tmp = list.at(i)).toInt();
-  }
-
-  if (config->readListEntry("RingDiffs", list)) {
-    for(int i=0;i<5;i++)
-      ringDiff[i] = (tmp = list.at(i)).toInt();
-  }
-
-  setFieldValues();
-}
-
-void Board::saveRating(KConfig *config)
-{
-  QString entry;
-
-  entry.sprintf("%d,%d,%d,%d,%d", stoneValue[1], stoneValue[2],
-		stoneValue[3], stoneValue[4], stoneValue[5]);
-  config->writeEntry("StoneValues", entry);
-
-  entry.sprintf("%d", moveValue[0]);
-  for(int i=1;i<Move::typeCount;i++)
-    entry += QString(", %1").arg( moveValue[i] );
-  config->writeEntry("MoveValues", entry);
-
-  entry.sprintf("%d", connectValue[0]);
-  for(int i=1;i<ConnectCounter::connectCount;i++)
-    entry += QString(", %1").arg( connectValue[i] );
-  config->writeEntry("ConnectValues", entry);
-
-  entry.sprintf("%d,%d,%d,%d,%d", ringValue[0], ringValue[1],
-		ringValue[2], ringValue[3], ringValue[4]);
-  config->writeEntry("RingValues", entry);
-
-  entry.sprintf("%d,%d,%d,%d,%d", ringDiff[0], ringDiff[1],
-		ringDiff[2], ringDiff[3], ringDiff[4]);
-  config->writeEntry("RingDiffs", entry);
-}
-
 
 
 void Board::begin(int startColor)
 {
-	int i;
-	
-	for(i=0;i<AllFields;i++)
-	  field[i] = startBoard[i];
-	storedFirst = storedLast = 0;
-	color = startColor;
-	color1Count = color2Count = 14;
-        random.setSeed(0); // Initialize random sequence
+  int i;
+  
+  for(i=0;i<AllFields;i++)
+    field[i] = startBoard[i];
+  storedFirst = storedLast = 0;
+  color = startColor;
+  color1Count = color2Count = 14;
+  random.setSeed(0); // Initialize random sequence
 }
 
 void Board::clear()
 {
-	int i;
-	
-	for(i=0;i<AllFields;i++)
-	  field[i] = (startBoard[i] == out) ? out: free;
-	storedFirst = storedLast = 0;
-	color1Count = color2Count = 0;
+  int i;
+  
+  for(i=0;i<AllFields;i++)
+    field[i] = (startBoard[i] == out) ? out: free;
+  storedFirst = storedLast = 0;
+  color1Count = color2Count = 0;
 }
 
 /* generate moves starting at field <startField> */
@@ -656,7 +613,7 @@ int Board::movesStored()
  */
 void Board::countFrom(int startField, int color, 
 		      MoveTypeCounter& TCounter,
-		      ConnectCounter& CCounter)
+		      InARowCounter& CCounter)
 {
   int d, dir, c, actField, c2;
   bool left, right;
@@ -677,7 +634,7 @@ void Board::countFrom(int startField, int color,
     
     /* 2nd == color */
     
-    CCounter.incr( ConnectCounter::connect2 );
+    CCounter.incr( InARowCounter::inARow2 );
 
     /* left side move 2 */
     left = (field[startField+direction[d-1]] == free);
@@ -722,7 +679,7 @@ void Board::countFrom(int startField, int color,
     
     /* 3nd == color */
 
-    CCounter.incr( ConnectCounter::connect3 );
+    CCounter.incr( InARowCounter::inARow3 );
 
     /* left side move 3 */
     if (left) {
@@ -785,7 +742,7 @@ void Board::countFrom(int startField, int color,
 
     /* 4nd == color */
 
-    CCounter.incr( ConnectCounter::connect4 );
+    CCounter.incr( InARowCounter::inARow4 );
 
     /* 5th field */
     c = field[actField += dir];
@@ -794,7 +751,7 @@ void Board::countFrom(int startField, int color,
 
     /* 4nd == color */
 
-    CCounter.incr( ConnectCounter::connect5 );
+    CCounter.incr( InARowCounter::inARow5 );
   }
 }
 
@@ -820,7 +777,7 @@ void indent(int d)
 int Board::validState()
 {
   MoveTypeCounter tc;
-  ConnectCounter  cc;
+  InARowCounter  cc;
 
   int c1 = 0, c2 = 0;
   int i,j, moveCount, res;
@@ -858,22 +815,22 @@ int Board::validState()
 
 
 
-/* Calculate a rating for actual position
+/* Calculate a evaluation for actual position
  * 
  * A higher value means a better position for opponent
  * NB: This means a higher value for better position of
  *     'color before last move'
  */
-int Board::calcValue()
+int Board::calcEvaluation()
 {
   MoveTypeCounter tcColor, tcOpponent;
-  ConnectCounter  ccColor, ccOpponent;
+  InARowCounter  ccColor, ccOpponent;
 
   int f,i,j;
 
   /* different evaluation types */
   int fieldValueSum=0, stoneValueSum=0;
-  int moveValueSum=0, connectValueSum=0;
+  int moveValueSum=0, inARowValueSum=0;
   int valueSum;
 
   /* First check simple winner condition */
@@ -902,32 +859,32 @@ int Board::calcValue()
       valueSum = 16000;
     else {
 
-      for(int i=0;i < Move::typeCount;i++)
-	moveValueSum += moveValue[i] * 
-	  (tcOpponent.get(i) - tcColor.get(i)) /2;
+      for(int t=0;t < Move::typeCount;t++)
+	moveValueSum += _evalScheme->moveValue(t) * 
+	  (tcOpponent.get(t) - tcColor.get(t));
       
-      for(int i=0;i < ConnectCounter::connectCount;i++)
-	connectValueSum += connectValue[i] * 
-	  (ccOpponent.get(i) - ccColor.get(i)) /2;
+      for(int i=0;i < InARowCounter::inARowCount;i++)
+	inARowValueSum += _evalScheme->inARowValue(i) * 
+	  (ccOpponent.get(i) - ccColor.get(i));
       
       if (color == color2)
-	stoneValueSum = stoneValue[14 - color1Count] - 
-	  stoneValue[14 - color2Count];
+	stoneValueSum = _evalScheme->stoneValue(14 - color1Count) - 
+	  _evalScheme->stoneValue(14 - color2Count);
       else
-	stoneValueSum = stoneValue[14 - color2Count] - 
-	  stoneValue[14 - color1Count];
+	stoneValueSum = _evalScheme->stoneValue(14 - color2Count) - 
+	  _evalScheme->stoneValue(14 - color1Count);
       
       valueSum = fieldValueSum + moveValueSum + 
-	connectValueSum + stoneValueSum;
+	inARowValueSum + stoneValueSum;
     }
   }
 
 #ifdef MYTRACE
   if (spyLevel>2) {
     indent(spyDepth);
-    printf("Eval %d (field %d, move %d, connect %d, stone %d)\n",
+    printf("Eval %d (field %d, move %d, inARow %d, stone %d)\n",
 	   valueSum, fieldValueSum, moveValueSum,
-	   connectValueSum, stoneValueSum );
+	   inARowValueSum, stoneValueSum );
   }
 #endif
 
@@ -936,42 +893,42 @@ int Board::calcValue()
 
 bool Board::isConsistent()
 {
-        int c1 = 0, c2 = 0;
-	int i,j;
-	
-	for(i=0;i<RealFields;i++) {		  
-		j=field[order[i]];
-		if (j == color1) c1++;
-		if (j == color2) c2++;
-	}
-	return (color1Count == c1 && color2Count == c2); 
+  int c1 = 0, c2 = 0;
+  int i,j;
+  
+  for(i=0;i<RealFields;i++) {		  
+    j=field[order[i]];
+    if (j == color1) c1++;
+    if (j == color2) c2++;
+  }
+  return (color1Count == c1 && color2Count == c2); 
 }
 
-void Board::changeRating()
+void Board::changeEvaluation()
 {
-	int i,tmp;
-	
-	/* innermost ring */
-	tmp=fieldValue[1];
-	for(i=1;i<6;i++)
-	  fieldValue[i] = fieldValue[i+1];
-	fieldValue[6] = tmp;
-	
-	tmp=fieldValue[7];
-	for(i=7;i<18;i++)
-	  fieldValue[i] = fieldValue[i+1];
-	fieldValue[18] = tmp;
-	
-	tmp=fieldValue[19];
-	for(i=19;i<36;i++)
-	  fieldValue[i] = fieldValue[i+1];
-	fieldValue[36] = tmp;
-
-	/* the outermost ring */
-	tmp=fieldValue[37];
-	for(i=37;i<60;i++)
-	  fieldValue[i] = fieldValue[i+1];
-	fieldValue[60] = tmp;
+  int i,tmp;
+  
+  /* innermost ring */
+  tmp=fieldValue[1];
+  for(i=1;i<6;i++)
+    fieldValue[i] = fieldValue[i+1];
+  fieldValue[6] = tmp;
+  
+  tmp=fieldValue[7];
+  for(i=7;i<18;i++)
+    fieldValue[i] = fieldValue[i+1];
+  fieldValue[18] = tmp;
+  
+  tmp=fieldValue[19];
+  for(i=19;i<36;i++)
+    fieldValue[i] = fieldValue[i+1];
+  fieldValue[36] = tmp;
+  
+  /* the outermost ring */
+  tmp=fieldValue[37];
+  for(i=37;i<60;i++)
+    fieldValue[i] = fieldValue[i+1];
+  fieldValue[60] = tmp;
 }
 
 /*
@@ -1194,7 +1151,7 @@ int Board::search(int depth, int alpha, int beta)
 	  else {
 	    ratedPositions++;
 	    
-	    value = calcValue();
+	    value = calcEvaluation();
 	  }
 	  takeBack();
 
@@ -1253,6 +1210,11 @@ Move& Board::bestMove()
 {
 	int alpha=-15000,beta=15000;
 	int nalpha,nbeta, actValue;
+
+	if (!_evalScheme) {
+	  // Use default values if not set
+	  setEvalScheme();
+	}
 	
 	pv.clear(realMaxDepth);
 	
@@ -1345,7 +1307,7 @@ Move& Board::bestMove()
 
 	/* If Spy is On, we want replayable search: don't change rating! */
 	if (spyLevel==0)
-	  changeRating();
+	  changeEvaluation();
 	else {
 	  printf(">>> Got Move : ");
 	  pv[0].print();
