@@ -16,7 +16,7 @@
 
 class Listener {
  public:
-  Listener(const char*,int,struct sockaddr_in,bool);
+  Listener(const char*,int,struct sockaddr_in,bool=true);
   
   char host[100];
   int port;
