@@ -8,7 +8,6 @@
 #include <qlayout.h>
 #include <qlabel.h>
 
-#include <kwm.h>
 #include <klocale.h>
 #include <kapp.h>
 
@@ -106,10 +105,8 @@ void Spy::update(int depth, int value, Move& m, bool wait)
 	next = false;
 	
 	if (depth>BoardCount-1) return;
-	board.showMove(m,3);
-	actBoard[depth]->copyPosition();
-	actBoard[depth]->draw();
-	board.showMove(m,0);	
+	actBoard[depth]->showMove(m,3);
+	//	actBoard[depth]->showMove(m,0,false);
 
 	if (!wait) {
 	  actLabel[depth]->setText("---");
@@ -118,8 +115,7 @@ void Spy::update(int depth, int value, Move& m, bool wait)
 
 	if (depth<BoardCount-1) {
 	  board.playMove(m);
-	  actBoard[depth+1]->copyPosition();
-	  actBoard[depth+1]->draw();
+	  actBoard[depth+1]->updatePosition(true);
 	  actLabel[depth+1]->setNum(value);
 	  board.takeBack();
 
@@ -136,15 +132,12 @@ void Spy::update(int depth, int value, Move& m, bool wait)
 void Spy::updateBest(int depth, int value, Move& m, bool cutoff)
 {
   if (depth>BoardCount-1) return;
-  board.showMove(m,3);
-  bestBoard[depth]->copyPosition();
-  bestBoard[depth]->draw();
-  board.showMove(m,0);
+  bestBoard[depth]->showMove(m,3);
+  //  board.showMove(m,0);
 
   if (depth<BoardCount-1) {
     board.playMove(m);
-    bestBoard[depth+1]->copyPosition();
-    bestBoard[depth+1]->draw();
+    bestBoard[depth+1]->updatePosition(true);
 
     QString tmp;
     tmp.setNum(value);
