@@ -9,16 +9,17 @@
 #include <kapp.h>
 #include <kstddirs.h>
 #include <kmessagebox.h>
-#include <kstatusbar.h>
 #include <ktoolbar.h>
 #include <kmainwindow.h>
 #include <kmenubar.h>
-#include <khelpmenu.h>
 #include <kconfig.h>
 #include <klocale.h>
 #include <kaccel.h>
 #include <kkeydialog.h>
 #include <kiconloader.h>
+#include <kaction.h>
+#include <kstdaction.h>
+#include <kaudioplayer.h>
 
 #include "toplevel.h"
 #include "ledmeter.h"
@@ -44,17 +45,17 @@ struct SLevel
 
 SLevel levels[MAX_LEVELS] =
 {
+    { 1, 0.4 },
     { 1, 0.6 },
-    { 1, 0.8 },
+    { 2, 0.5 },
     { 2, 0.7 },
     { 2, 0.8 },
-    { 2, 0.9 },
+    { 3, 0.6 },
     { 3, 0.7 },
     { 3, 0.8 },
-    { 3, 0.9 },
+    { 4, 0.6 },
     { 4, 0.7 },
     { 4, 0.8 },
-    { 4, 0.9 },
     { 5, 0.7 },
     { 5, 0.8 },
     { 5, 0.9 },
@@ -223,6 +224,22 @@ KAstTopLevel::KAstTopLevel() : KMainWindow(0)
     shieldLCD->setFixedHeight( 20 );
     hbd->addWidget( shieldLCD );
 
+    hbd->addSpacing( 10 );
+
+    pm.load( sprites_prefix + "powerups/shoot.png" );
+    label = new QLabel( mainWin );
+    label->setPixmap( pm );
+    label->setFixedWidth( label->sizeHint().width() );
+    label->setPalette( pal );
+    hbd->addWidget( label );
+
+    shootLCD = new QLCDNumber( 1, mainWin );
+    shootLCD->setFrameStyle( QFrame::NoFrame );
+    shootLCD->setSegmentStyle( QLCDNumber::Flat );
+    shootLCD->setPalette( pal );
+    shootLCD->setFixedHeight( 20 );
+    hbd->addWidget( shootLCD );
+
     hbd->addStretch( 1 );
 
     label = new QLabel( i18n( "Fuel" ), mainWin );
@@ -291,32 +308,16 @@ KAstTopLevel::~KAstTopLevel()
 
 void KAstTopLevel::createMenuBar()
 {
-    menu = new KMenuBar( this );
+    KStdAction::openNew( this, SLOT( slotNewGame() ), actionCollection(), "game_new" );
+    (void)new KAction( i18n("Show &Highscores..."), 0, this, 
+          SLOT( slotShowHighscores() ), actionCollection(), "game_hiscores" );
+    KStdAction::quit(this, SLOT( slotQuit() ), actionCollection(), "game_quit");
 
-    KPopupMenu *fileMenu = new KPopupMenu;
-    fileMenu->insertItem( SmallIcon("filenew"), i18n( "&New Game" ), this,
-                          SLOT(slotNewGame()), CTRL+Key_N );
-    fileMenu->insertItem( i18n("Show &Highscores..."), this,
-                          SLOT( slotShowHighscores() ), CTRL+Key_H );
-    fileMenu->insertSeparator( );
-    fileMenu->insertItem( SmallIcon("exit"), i18n( "&Quit" ), this, SLOT(slotQuit()),
-                          CTRL+Key_Q );
+//settings
+    KStdAction::keyBindings(this, SLOT( slotKeyConfig() ), actionCollection());
+    KStdAction::preferences(this, SLOT( slotPref() ), actionCollection());
 
-    KPopupMenu *optionsMenu = new KPopupMenu( NULL, "popupOptions" );
-    optionsMenu->insertItem( i18n("Configure &Key Bindings..."), this,
-                             SLOT( slotKeyConfig() ) );
-    optionsMenu->insertItem( SmallIcon("configure"), i18n("&Preferences..."), this,
-                             SLOT( slotPref() ) );
-
-    KHelpMenu *help = new KHelpMenu(this,
-                                    i18n("Asteroids %1\n\n"
-                                         "by Martin R. Jones (mjones@kde.org)")
-                                    .arg(KASTEROIDS_VERSION));
-
-    menu->insertItem( i18n( "&File" ), fileMenu );
-    menu->insertItem( i18n( "&Settings" ), optionsMenu );
-    menu->insertSeparator();
-    menu->insertItem( i18n( "&Help" ), help->menu() );
+    createGUI("kasteroidsui.rc");
 }
 
 
@@ -348,6 +349,16 @@ void KAstTopLevel::readSettings()
 
 void KAstTopLevel::playSound( const char *snd )
 {
+// KAudioPlayer sometimes seem to be a little bit...slow
+// it takes a moment until the sound is played - maybe an arts problem
+// but it's a good temporary solution
+
+    QString *filename = soundDict[ snd ];
+    if (filename) {
+        KAudioPlayer::play(*filename);
+    }
+
+return; // remove this and the above when the sound below is working correctly
 #ifdef KA_ENABLE_SOUND
     if ( sound ) {
         QString *filename = soundDict[ snd ];
@@ -635,6 +646,7 @@ void KAstTopLevel::slotUpdateVitals()
 {
     brakesLCD->display( view->brakeCount() );
     shieldLCD->display( view->shieldCount() );
+    shootLCD->display( view->shootCount() );
 //    teleportsLCD->display( view->teleportCount() );
     powerMeter->setValue( view->power() );
 }
