@@ -2,10 +2,7 @@
 #ifndef __KAST_TOPLEVEL_H__
 #define __KAST_TOPLEVEL_H__
 
-#include <kstatusbar.h>
-#include <ktoolbar.h>
 #include <kmainwindow.h>
-#include <kmenubar.h>
 #include <kaccel.h>
 #include <qdict.h>
 #include <qmap.h>
@@ -54,7 +51,6 @@ private slots:
 
 private:
     KAsteroidsView *view;
-    KMenuBar *menu;
     QLCDNumber *scoreLCD;
     QLCDNumber *levelLCD;
     QLCDNumber *shipsLCD;
@@ -63,6 +59,7 @@ private:
 //    QLCDNumber *bombsLCD;
     QLCDNumber *brakesLCD;
     QLCDNumber *shieldLCD;
+    QLCDNumber *shootLCD;
     KALedMeter *powerMeter;
 
     HighscoreList *highscore;
