@@ -31,8 +31,7 @@ public:
     void rotateRight( bool r ) { rotateR = r; rotateSlow = 5; }
     void thrust( bool t ) { thrustShip = t && shipPower > 0; }
     void shoot( bool s ) { shootShip = s; shootDelay = 0; }
-    void setShield( bool s )
-        { shieldOn = s && mShieldCount; shieldTimer->stop(); }
+    void setShield( bool s );
     void teleport( bool te) { teleportShip = te && mTeleportCount; }
     void brake( bool b );
     void pause( bool p);
@@ -47,6 +46,7 @@ public:
     int teleportCount() const { return mTeleportCount; }
     int brakeCount() const { return mBrakeCount; }
     int shieldCount() const { return mShieldCount; }
+    int shootCount() const { return mShootCount; }
 
 signals:
     void shipKilled();
@@ -109,6 +109,7 @@ private:
     int mBrakeCount;
     int mShieldCount;
     int mTeleportCount;
+    int mShootCount;
 
     double shipDx;
     double shipDy;
