@@ -1,11 +1,11 @@
 /*
 
-    $Id: kmahjongg.h,v 1.14 1999/12/13 14:19:47 waba Exp $
+    $Id: kmahjongg.h,v 1.18 2000/09/25 20:36:43 gebauer Exp $
 
     kmahjongg, the classic mahjongg game for KDE project
 
     Requires the Qt widget libraries, available at no cost at
-    http://www.troll.no 
+    http://www.troll.no
 
     Copyright (C) 1997 Mathias Mueller   <in5y158@public.uni-hamburg.de>
 
@@ -13,15 +13,15 @@
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
-  
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-  
+
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.    
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 */
 
@@ -34,16 +34,16 @@ class QLabel;
 #include <qfiledlg.h>
 
 #include <kapp.h>
-#include <kmessagebox.h> 
+#include <kmessagebox.h>
 #include <krandomsequence.h>
 
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 #include "KmTypes.h"
 #include "Tileset.h"
 #include "Background.h"
 #include "Preferences.h"
 #include "PrefsDlg.h"
-#include "GameTimer.h" 
+#include "GameTimer.h"
 #include "GameNum.h"
 #include "BoardLayout.h"
 #include "Preview.h"
@@ -64,17 +64,17 @@ static const char *gameMagic = "kmahjongg-game-v1.0";
 typedef struct gamedata {
     int      allow_undo;
     int      allow_redo;
-    UCHAR    Board[BoardLayout::depth][BoardLayout::height][BoardLayout::width]; 
-    USHORT   TileNum;          
-    USHORT   MaxTileNum;       
+    UCHAR    Board[BoardLayout::depth][BoardLayout::height][BoardLayout::width];
+    USHORT   TileNum;
+    USHORT   MaxTileNum;
     UCHAR    Mask[BoardLayout::depth][BoardLayout::height][BoardLayout::width];
     UCHAR    hilighted[BoardLayout::depth][BoardLayout::height][BoardLayout::width];
     POSITION MoveList[BoardLayout::maxTiles];
     void putTile( short e, short y, short x, UCHAR f )
     {
-	    
+	
 
-        Board[e][y][x] = Board[e][y+1][x] = 
+        Board[e][y][x] = Board[e][y+1][x] =
 		   Board[e][y+1][x+1] = Board[e][y][x+1] = f;
     }
     void putTile( POSITION& pos )
@@ -94,7 +94,7 @@ typedef struct gamedata {
     int shadowHeight(int z, int y, int x) {
 
 
-    if ((z>=BoardLayout::depth||y>=BoardLayout::height||x>=BoardLayout::width)) 
+    if ((z>=BoardLayout::depth||y>=BoardLayout::height||x>=BoardLayout::width))
 	return 0;
 	
 
@@ -114,8 +114,8 @@ typedef struct gamedata {
 	}
 	return h;
     }
-    
-    
+
+
 } GAMEDATA;
 
 
@@ -149,7 +149,7 @@ class BoardWidget : public QWidget
         void setShowMatch( bool );
 	void tileSizeChanged(void);
 	long getGameNum(void) {return gameGenerationNum;};
-	QString &getBoardName(void){return theBoardLayout.getFilename();}; 
+	QString &getBoardName(void){return theBoardLayout.getFilename();};
 	QString &getLayoutName(void) {return theBoardLayout.getFilename();};
 
 	
@@ -158,15 +158,15 @@ class BoardWidget : public QWidget
         void demoMoveTimeout();
         void matchAnimationTimeout();
 	void setDisplayedWidth();
-        bool loadTileset    ( const char* );
-        bool loadBoardLayout( const char* );
+        bool loadTileset    ( const QString & );
+        bool loadBoardLayout( const QString& );
         bool loadBoard      ( );
         void updateScaleMode (void);
         void drawBoard(bool deferUpdate = true);
-        bool loadBackground ( const char*, bool bShowError = true );
+        bool loadBackground ( const QString&, bool bShowError = true );
     signals:
-        void statusTextChanged ( const char*, long );
-        void message           ( const char* );
+        void statusTextChanged ( const QString&, long );
+        void message           ( const QString& );
         void tileNumberChanged ( int iMaximum, int iCurrent );
         void demoModeChanged   ( bool bActive );
 
@@ -181,8 +181,8 @@ class BoardWidget : public QWidget
         void paintEvent      ( QPaintEvent* );
         void mousePressEvent ( QMouseEvent* );
 
-        void setStatusText ( const char* );
-        void showMessage   ( const char* );
+        void setStatusText ( const QString& );
+        void showMessage   ( const QString& );
         void cancelUserSelectedTiles();
         void drawTileNumber();
 
@@ -199,7 +199,7 @@ class BoardWidget : public QWidget
         short findAllMatchingTiles( POSITION& );
         void stopMatchAnimation();
 	void stackTiles(unsigned char t, unsigned short h, unsigned short x,unsigned  short y);
-	void initialiseRemovedTiles(void); 
+	void initialiseRemovedTiles(void);
 
 	int requiredWidth(void);
 	int requiredHeight(void);
@@ -216,7 +216,7 @@ class BoardWidget : public QWidget
 	
 	KRandomSequence random;
 	
-	Tileset  theTiles;         
+	Tileset  theTiles;
 	Background theBackground;
 	
 	
@@ -263,7 +263,7 @@ class BoardWidget : public QWidget
 	unsigned char removedSeason[4];
 	
 public:
-        GAMEDATA Game;         
+        GAMEDATA Game;
 };
 
 
@@ -272,9 +272,9 @@ public:
 
 /**
     ...
-    @author Mathias 
+    @author Mathias
 */
-class KMahjonggWidget : public KTMainWindow
+class KMahjonggWidget : public KMainWindow
 {
     Q_OBJECT
 
@@ -287,14 +287,14 @@ class KMahjonggWidget : public KTMainWindow
     public slots:
         void menuCallback( int );
         void startNewGame( int num = -1 );
-        void showStatusText ( const char* , long);
-        void showMessage    ( const char* );
+        void showStatusText ( const QString& , long);
+        void showMessage    ( const QString& );
         void showTileNumber( int iMaximum, int iCurrent );
         void demoModeChanged( bool bActive );
 		void gameOver( unsigned short removed, unsigned short cheats);
- 	void statusBarMode(int onOff); 
+ 	void statusBarMode(int onOff);
 	void backgroundMode();
-	void loadBoardLayout(const char *);
+	void loadBoardLayout(const QString&);
 	void setDisplayedWidth();
 	void newGame(void);
 	void timerReset(void);
@@ -327,21 +327,16 @@ class KMahjonggWidget : public KTMainWindow
         KStatusBar*  pStatusBar;
 	KToolBar     *toolBar;
         KMenuBar*    pMenuBar;
-	PrefsDlg     prefsDlg;
-	Preview      previewLoad;
-	Editor	     boardEditor;
+	PrefsDlg     *prefsDlg;
+	Preview      *previewLoad;
+	Editor*	     boardEditor;
 
         bool         bShowStatusbar;
         bool         bShowMatchingTiles;
         bool         bDemoModeActive;
 };
 
-			    
+			
 
 
 #endif
-
-
-
-
-
