@@ -1,8 +1,6 @@
 #include "main.h"
 
-#include <time.h>
-
-#include <qdatetime.h>
+#include <qwhatsthis.h>
 
 #include <kapp.h>
 #include <klocale.h>
@@ -14,12 +12,13 @@
 #include <khelpmenu.h>
 #include <kstdaction.h>
 #include <kkeydialog.h>
+#include <kstatusbar.h>
 
 #include "version.h"
 #include "status.h"
 
 MainWidget::MainWidget()
-: levelAction(NbLevels)
+: KMainWindow(0), levelAction(NbLevels)
 {
 	installEventFilter(this);
 
@@ -29,8 +28,10 @@ MainWidget::MainWidget()
 			SLOT(setKeyboardEnabled(bool)));
 	connect(status, SIGNAL(gameStateChanged(GameState)),
 			SLOT(gameStateChanged(GameState)));
+	connect(status, SIGNAL(message(const QString &)),
+			statusBar(), SLOT(message(const QString &)));
 
-	// File & Popup
+	// Game & Popup
 	KStdAction::openNew(status, SLOT(restartGame()),
 						actionCollection(), "game_new");
 	(void)new KAction(i18n("Pause"), Key_P, status, SLOT(pauseGame()),
@@ -91,24 +92,24 @@ MainWidget::MainWidget()
 	for (uint i=0; i<levelAction.size(); i++)
 		levelAction[i]->setExclusiveGroup("level");
 
+	// status bar
+	QWhatsThis::add(statusBar(), i18n("Game status"));
+
 	createGUI();
 	readSettings();
-	setView(status);
-	updateRects(); // #### should be in KTMainWindow::setView
+	setCentralWidget(status);
 }
 
 #define MENUBAR_ACTION \
-    ((KToggleAction *)actionCollection() \
-	 ->action(KStdAction::stdName(KStdAction::ShowMenubar)))
+    ((KToggleAction *)action(KStdAction::stdName(KStdAction::ShowMenubar)))
 
-#define PAUSE_ACTION \
-    ((KToggleAction *)actionCollection()->action("game_pause"))
+#define PAUSE_ACTION ((KToggleAction *)action("game_pause"))
 
 void MainWidget::readSettings()
 {
-	GameType type = OptionDialog::readLevel();
-	levelAction[type]->setChecked(TRUE);
-	status->newGame(type);
+	Level l = OptionDialog::readLevel();
+	if ( l.type!=Custom ) levelAction[l.type]->setChecked(true);
+	status->newGame(l);
 
 	bool visible = OptionDialog::readMenuVisible();
 	MENUBAR_ACTION->setChecked(visible);
@@ -120,25 +121,39 @@ void MainWidget::readSettings()
 void MainWidget::changeLevel(uint i)
 {
 	if ( !levelAction[i]->isChecked() ) return;
-	GameType lev = (GameType)i;
-	if ( !status->newGame(lev) ) { // level unchanged
-		levelAction[lev]->setChecked(TRUE);
-		return;
-	}
-	
-	OptionDialog::writeLevel(lev);
+
+	GameType type = (GameType)i;
+	Level l;
+	if ( type==Custom ) {
+		levelAction[Custom]->setChecked(false);
+		l = status->currentLevel();
+		type = l.type;
+		CustomDialog cu(l, this);
+		if ( !cu.exec() ) { // level unchanged
+			if ( type!=Custom ) levelAction[type]->setChecked(true);
+			return;
+		}
+	} else l = LEVELS[i];
+
+	status->newGame(l);
+	OptionDialog::writeLevel(l);
 }
 
 bool MainWidget::eventFilter(QObject *, QEvent *e)
 {
 	QPopupMenu *popup;
 	switch (e->type()) {
-	 case QEvent::MouseButtonPress :
-		if ( ((QMouseEvent *)e)->button()!=RightButton ) return FALSE;
+	case QEvent::MouseButtonPress :
+		if ( ((QMouseEvent *)e)->button()!=RightButton ) return false;
 		popup = (QPopupMenu*)factory()->container("popup", this);
-		popup->popup(QCursor::pos());
-		return TRUE;
-	 default : return FALSE;
+		if ( popup ) popup->popup(QCursor::pos());
+		return true;
+	case QEvent::LayoutHint:
+		setFixedSize(minimumSize()); // because QMainWindow and KMainWindow
+		                             // do not manage fixed central widget and
+		                             // hidden menubar ...
+		return false;
+	default : return false;
 	}
 }
 
@@ -146,15 +161,7 @@ void MainWidget::toggleMenubar()
 {
 	bool b = MENUBAR_ACTION->isChecked();
 	if (b) menuBar()->show();
-	else {
-		menuBar()->hide();
-	
-		// #### sort of hack : because KTMainWindow does not manage correctly
-		// main widget with a fixed layout
-		updateRects();
-		adjustSize();
-	}
-
+	else menuBar()->hide();
 	OptionDialog::writeMenuVisible(b);
 }
 
@@ -168,24 +175,21 @@ void MainWidget::setKeyboardEnabled(bool enable)
 
 void MainWidget::configureKeys()
 {
-	KKeyDialog::configureKeys(actionCollection(), xmlFile());
+	KKeyDialog::configureKeys(actionCollection(), xmlFile(), true, this);
 }
 
 void MainWidget::gameStateChanged(GameState s)
 {
 	switch (s) {
 	case Stopped:
-		PAUSE_ACTION->setEnabled(FALSE);
+		PAUSE_ACTION->setEnabled(false);
         break;
 	case Paused:
 		PAUSE_ACTION->setText(i18n("&Resume"));
 		break;
 	case Playing:
 		PAUSE_ACTION->setText(i18n("&Pause"));
-		PAUSE_ACTION->setEnabled(TRUE);
-		break;
-    case GameOver:
-		PAUSE_ACTION->setEnabled(FALSE);
+		PAUSE_ACTION->setEnabled(true);
 		break;
 	}
 }
@@ -199,8 +203,8 @@ int main(int argc, char **argv)
     KAboutData aboutData("kmines", I18N_NOOP("KMines"), LONG_VERSION,
 						 DESCRIPTION, KAboutData::License_GPL,
 						 COPYLEFT, 0, HOMEPAGE);
-    aboutData.addAuthor("Nicolas Hadacek", 0, "hadacek@kde.org");
-	aboutData.addCredit("Andreas Zehender", "Smiley pixmaps");
+    aboutData.addAuthor("Nicolas Hadacek", 0, EMAIL);
+	aboutData.addCredit("Andreas Zehender", I18N_NOOP("Smiley pixmaps"));
     KCmdLineArgs::init(argc, argv, &aboutData);
 
     KApplication a;
