@@ -1,14 +1,14 @@
 #ifndef MAIN_H
 #define MAIN_H
 
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 #include <kaction.h>
 
 #include "defines.h"
 
 class Status;
 
-class MainWidget : public KTMainWindow
+class MainWidget : public KMainWindow
 {
   Q_OBJECT
 	
