@@ -25,7 +25,7 @@
 #include <krandomsequence.h>
 
 
-typedef enum _cardtype { // I don't use this anymore. But it helps to understand the numbers :)
+enum _cardtype { // I don't use this anymore. But it helps to understand the numbers :)
 	        DECK=0,
 	        CA=1,SA=2,HA=3,DA=4,
 	        CK=5,SK=6,HK=7,DK=8,
@@ -49,6 +49,8 @@ class QLabel;
 class QFrame;  
 class QLineEdit;
 class QFrame;
+class QHBoxLayout;
+class QVBoxLayout;
 
 // KDE classes
 class KAccel;
@@ -89,11 +91,19 @@ public:
 	
 	void updateLHLabel();//tomporary function, only called once
 
+	bool getSound() const			{ return sound; }
+	bool getBlinking() const		{ return blinking; }
+	bool getAdjust() const			{ return adjust; }
+
 signals:
 	void changeLastHand(QString newHand, bool lastHand = true);
 	void showClickToHold(bool show);
+	void statusBarMessage(QString);
+	void clearStatusBar();
 
 protected:
+	void loadDeck(QString path);
+	void loadCards(QString path);
 	void setSize(int players); // will resize the window depending on the number of players
 	void readOptions();
 	void drawCards(Player* p, bool skip[], bool done[]);
@@ -164,6 +174,12 @@ protected:
 	int getSuitePoints(int suite);
 
 public slots:
+	void slotCardDeck();
+	void toggleSound();
+	void toggleAdjust();
+	void toggleBlinking();
+	void slotPreferences();
+	
 	bool initSound();
 
 	/**
@@ -175,12 +191,18 @@ public slots:
 
 	bool loadGame(KConfig* conf);
 	bool loadGame();
-	void commandCallback(int id);
+//	void commandCallback(int id);
 	void newGame();
 	void saveGame();
 
 protected slots:
 	
+	void exchangeCard1();
+	void exchangeCard2();
+	void exchangeCard3();
+	void exchangeCard4();
+	void exchangeCard5();
+
 	void bTimerEvent();
 	void drawCardsEvent();
 	void drawClick();
@@ -195,6 +217,8 @@ protected slots:
 	void toggleHeld(); // play a sound
 
 private:
+	QVBoxLayout* topLayout;
+	QHBoxLayout* inputLayout;
 	int allPlayersNr; // used for constructing and deleting only
 
 	PlayerBox** playerBox;        //one box per player
@@ -218,7 +242,6 @@ private:
 	QPushButton 	*drawButton;    // the main Button
 	QLabel 		*wonLabel;      // the winner
 	QLabel 		*clickToHold; 
-	QLabel 		*weWillAdjustLabel; 
 	bool		adjust;
 
 	QTimer       *blinkTimer; // the winning cards will blink 
