@@ -36,39 +36,39 @@
  *******************************************************************
  */
 
-#include <qdir.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
+
+#include <qdir.h>
 #include <qaccel.h>
 #include <qpopupmenu.h>
-#include <kapp.h>
 #include <qpushbutton.h>
 #include <qlistbox.h>
 #include <qdatetime.h>
 #include <qlabel.h>
 #include <qlineedit.h>
-#include <kconfig.h>
-#include <kcolordlg.h>
 #include <qregexp.h>
 #include <qtimer.h>
 #include <qlayout.h>
+
+#include <kapp.h>
+#include <kdebug.h>
+#include <kconfig.h>
+#include <kcolordlg.h>
 #include <kseparator.h>
-#include <kwm.h>
-#include <qmessagebox.h>
+#include <kmessagebox.h>
 #include <kstddirs.h>
 #include <kglobal.h>
 #include <kiconloader.h>
 #include <khelpmenu.h>
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include "Score.h"
 #include "app.h"
-#include "about.h"
 #include "playsound.h"
+#include "version.h"
 
 #define APPDATA(x) KGlobal::dirs()->findResource("appdata", x)
 #define PICDATA(x) KGlobal::dirs()->findResource("appdata", QString("pics/")+ x)
@@ -124,10 +124,10 @@ const int SB_SCOREH	= 2;
 const int SB_SCOREC	= 3;
 const int SB_TURN       = 4;
 
-App::App() : KTMainWindow() {
+App::App() : KMainWindow(0) {
   highscore.resize(0);
   readHighscore();
-  setCaption( kapp->caption() );
+  setCaption("");
 
   // create reversi board
   b = new Board(this);
@@ -140,10 +140,7 @@ App::App() : KTMainWindow() {
   tb->show();
   sb->show();
   menu->show();
-  setView(b);
-  addToolBar(tb);
-  setStatusBar(sb);
-  setMenu(menu);
+  setCentralWidget(b);
 
   connect(b, SIGNAL(score()), this, SLOT(slotScore()));
   connect(b, SIGNAL(gameWon(int)), this, SLOT(slotGameEnded(int)));
@@ -161,14 +158,12 @@ App::App() : KTMainWindow() {
     if(conf->readNumEntry("Background", -1) != -1) {
       int i = conf->readNumEntry("Background");
       if(i == 1) {
-	int red, green, blue;
-	QString s = conf->readEntry("BackgroundColor");
-	sscanf((const char *)s, "%d %d %d", &red, &green, &blue);      
-	b->setColor(QColor(red, green, blue));
+	QColor s = conf->readColorEntry("BackgroundColor");
+	b->setColor(s);
       } else if(i == 2) {
 	QString s = conf->readEntry("BackgroundPixmap");
 	if(s.length() > 0) {
-	  QPixmap bg((const char *)s);
+	  QPixmap bg(s);
 	  if(bg.width())
 	    b->setPixmap(bg);
 	}
@@ -181,7 +176,6 @@ App::App() : KTMainWindow() {
     if(conf->readNumEntry("Zoom", -1) != -1) {      
       b->setZoom(conf->readNumEntry("Zoom", -1)); 
       b->setFixedSize(b->sizeHint());
-      updateRects();
     }
 
     // set toolbar position
@@ -203,39 +197,32 @@ App::App() : KTMainWindow() {
       if(!audioOK()) {
 	show();
 	kapp->processEvents();
-	QMessageBox::warning(this, i18n("Error"),
-			     i18n("A problem with the sound server "
-				  "occured!\nCannot enable sound "
-				  "support."), i18n("OK"));
+	KMessageBox::error(this,
+			   i18n("A problem with the sound server occured!\n"
+				"Cannot enable sound support."));
       }
     } else
       doneAudio(); // just to be sure
 #endif
   }
     
-  updateRects();
-  
   if(kapp->isRestored())
     restore(1);
 }
 
 
 App::~App() {
-  if(tb)
-    delete tb;
-  if(menu)
-    delete menu;
 }
 
 void App::createMenuBar() {
-  menu = new KMenuBar(this);
+  menu = menuBar();
 
   QPopupMenu *fm = new QPopupMenu;
-  fm->insertItem(i18n("&New game"), ID_GNEW);
-  fm->insertItem(i18n("&Load game"), ID_FLOAD);
-  fm->insertItem(i18n("&Save game"), ID_FSAVE);
+  fm->insertItem(SmallIcon("filenew"),i18n("&New game"), ID_GNEW);
+  fm->insertItem(SmallIcon("fileopen"),i18n("&Load game"), ID_FLOAD);
+  fm->insertItem(SmallIcon("filesave"),i18n("&Save game"), ID_FSAVE);
   fm->insertSeparator();
-  fm->insertItem(i18n("&Quit"), ID_FQUIT);
+  fm->insertItem(SmallIcon("exit"),i18n("&Quit"), ID_FQUIT);
 
   QPopupMenu *gm = new QPopupMenu;
   gm->insertItem(i18n("Get &hint"), ID_HHINT);
@@ -300,7 +287,7 @@ void App::createMenuBar() {
 	current = newmenu;
       }
 
-      current->insertItem((const char *)s, ID_PIXMAP + i);
+      current->insertItem(s, ID_PIXMAP + i);
     }
   }
   
@@ -315,7 +302,7 @@ void App::createMenuBar() {
   for(int i = ID_OSPEED+2; i < ID_OSPEED + 10; i++) {
     QString txt;
     txt.setNum(i - ID_OSPEED);
-    om_sp->insertItem((const char *)txt, i);
+    om_sp->insertItem(txt, i);
   }
   om_sp->insertItem(i18n("10 (slowest)"), ID_OSPEED+10);
   om->insertItem(i18n("Animation speed"), om_sp, ID_OSPEED);
@@ -324,16 +311,24 @@ void App::createMenuBar() {
   om->insertItem(i18n("S&ound"), ID_OSOUND);
 #endif
 
-  QPopupMenu *help = helpMenu(QString::null);  // Use our own About box
-  help = new QPopupMenu;
-  help->insertItem(i18n("&Contents"), ID_HCONTENTS);
-  help->insertSeparator();
-  help->insertItem(i18n("&About")+" "+kapp->name() + "...", ID_HABOUT);
-  help->insertItem(i18n("About &KDE..."), ID_HABOUTKDE);
+  QString s;
+  s = i18n("Version ");
+  s += KREVERSI_VERSION;
+  s += i18n("\n(c) 1997 Mario Weilguni <mweilguni@sime.com>\n\n" \
+    "This program is free software\npublished under the GNU General\n" \
+    "Public License (take a look\ninto help for details)\n\n" \
+    "Thanks to:\n" \
+    "\tMats Luthman for the game engine\n" \
+    "\t(I've ported it from his JAVA applet)\n\n" \
+    "\tStephan Kulow\n\tfor comments "\
+    "and bugfixes\n\n" \
+    "\tArne Klaassen\n\t "\
+    "for the raytraced chips");
+  QPopupMenu *help = helpMenu(s);
 
   menu->insertItem(i18n("&File"), fm);
   menu->insertItem(i18n("&Game"), gm);
-  menu->insertItem(i18n("&Options"), om);
+  menu->insertItem(i18n("&Settings"), om);
   menu->insertSeparator();
   menu->insertItem(i18n("&Help"), help);
   connect(menu, SIGNAL(activated(int)), this, SLOT(processEvent(int)));
@@ -368,7 +363,7 @@ void App::createMenuBar() {
 #define ICON(x) QPixmap(PICDATA(x))
 
 void App::createToolBar() {
-  tb = new KToolBar(this);
+  tb = toolBar();
 
   tb->insertButton(ICON("stop.xpm"), 
 		   ID_GSTOP, TRUE, i18n("Stop thinking"));
@@ -388,9 +383,9 @@ void App::createToolBar() {
 
 void App::createStatusBar() {
   sb = new KStatusBar(this);
-  sb->insertItem(i18n("XXXXX's turn"), SB_TURN);
-  sb->insertItem(i18n("You (XXXXX): 88"), SB_SCOREH);
-  sb->insertItem(i18n("Computer (XXXXX): 88"), SB_SCOREC);
+  sb->insertItem(i18n("XXXXX's turn"), SB_TURN,1);
+  sb->insertItem(i18n("You (XXXXX): 88"), SB_SCOREH,2);
+  sb->insertItem(i18n("Computer (XXXXX): 88"), SB_SCOREC,2);
 }
 
 
@@ -437,8 +432,8 @@ void App::processEvent(int itemid) {
       KConfig *config = kapp->config();
       config->setGroup("Savegame");
       b->saveGame(config);
-      QMessageBox::information(this, kapp->caption(),
-                               i18n("Game saved"), i18n("OK"));
+      KMessageBox::information(this,
+                               i18n("Game saved."));
     }
     break;
 
@@ -488,14 +483,12 @@ void App::processEvent(int itemid) {
   case ID_VZOOMIN:
     b->zoomIn();
     b->setFixedSize(b->sizeHint());
-    updateRects();
     kapp->config()->writeEntry("Zoom", b->getZoom());
     break;
     
   case ID_VZOOMOUT:
     b->zoomOut();
     b->setFixedSize(b->sizeHint());
-    updateRects();
     kapp->config()->writeEntry("Zoom", b->getZoom());
     break;
 
@@ -510,7 +503,6 @@ void App::processEvent(int itemid) {
   case ID_VZOOM200:
     b->setZoom(itemid - ID_VZOOMBASE);
     b->setFixedSize(b->sizeHint());
-    updateRects();
     kapp->config()->writeEntry("Zoom", b->getZoom());
     break;
 
@@ -547,7 +539,7 @@ void App::processEvent(int itemid) {
 
   case ID_COLOR:
     {
-      if(KColorDialog::getColor(c)) {
+      if(KColorDialog::getColor(c,this)) {
 	b->setColor(c);
 	kapp->config()->writeEntry("Background", 1);
 	s = QString("%1 %2 %3").arg(c.red()).arg(c.green()).arg(c.blue());
@@ -561,10 +553,9 @@ void App::processEvent(int itemid) {
     if(!audioOK()) {
       initAudio();
       if(!audioOK()) {
-	QMessageBox::warning(this, i18n("Error"), 
-			     i18n("A problem with the sound server "
-				  "occured!\nCannot enable sound "
-				  "support."), i18n("OK"));
+	KMessageBox::error(this,
+			   i18n("A problem with the sound server occured!\n"
+				"Cannot enable sound support."));
 	kapp->config()->writeEntry("Sound", 0);
       } else 
 	kapp->config()->writeEntry("Sound", 1);  
@@ -579,21 +570,6 @@ void App::processEvent(int itemid) {
     b->hint();
     break;
 
-  case ID_HABOUT:
-    {
-      QDialog *dlg = new About(0);
-      dlg->exec();
-      delete dlg;
-    }
-  break;
-
-  case ID_HABOUTKDE:
-    {
-	KHelpMenu hm;
-	hm.aboutKDE();
-    }
-    break;
-
   default:
     {
       if((itemid >= ID_PIXMAP) && (itemid < ID_PIXMAP + (int)backgroundPixmaps.count())) {
@@ -606,9 +582,10 @@ void App::processEvent(int itemid) {
       } else if((itemid >= ID_OSPEED) && (itemid <= ID_OSPEED + 10)) {
 	b->setAnimationSpeed(itemid - ID_OSPEED);
 	kapp->config()->writeEntry("AnimationSpeed", b->animationSpeed());
-      } else
-	QMessageBox::information(this, i18n("Information"), 
-				 i18n("not yet implemented"), i18n("Then do it!"));
+      } else {
+/*	KMessageBox::sorry(this,
+                                i18n("Sorry, not yet implemented!"));*/
+      }
     }
   }
   enableItems();
@@ -680,7 +657,7 @@ void App::slotGameEnded(int color) {
   if(color == Score::NOBODY) {
     playSound("reversi-drawn.wav");
     s = i18n("Game is drawn!\n\nYou     : %1\nComputer: %2").arg(winner).arg(loser);
-    QMessageBox::information(this, i18n("Game ended"), s, i18n("OK"));
+    KMessageBox::information(this, s, i18n("Game ended"));
   } else if(b->humanIs() == color) {
     // calculate score
     int  st = b->getStrength();
@@ -692,12 +669,12 @@ void App::slotGameEnded(int color) {
     playSound("reversi-won.wav");
     s = i18n("Congratulations, you have won!\n\nYou     : %1\nComputer: %2\nYour rating %3%%")
 	      .arg(winner).arg(loser).arg(score,1);
-    QMessageBox::information(this, i18n("Game ended"), s, i18n("OK"));
+    KMessageBox::information(this, s, i18n("Game ended"));
 
     // create highscore entry
     HighScore hs;
     QString name = getPlayerName();
-    strncpy(hs.name, (const char *)name, sizeof(hs.name) - 1);
+    strncpy(hs.name, name.utf8(), sizeof(hs.name) - 1);
     hs.color = b->humanIs();
     hs.winner = winner;
     hs.loser = loser;
@@ -712,7 +689,7 @@ void App::slotGameEnded(int color) {
     playSound("reversi-lost.wav");
     s = i18n("You have lost the game!\n\nYou     : %1\nComputer: %2")
 	      .arg(loser).arg(winner);
-    QMessageBox::information(this, i18n("Game ended"), s, i18n("OK"));
+    KMessageBox::information(this, s, i18n("Game ended"));
   }
 }
 
@@ -825,7 +802,7 @@ void App::readHighscore() {
       highscore.resize(i+1);
 
       HighScore hs;
-      sscanf((const char *)e, "%s %d %d %d %f %ld", 
+      sscanf((const char *)e.utf8(), "%s %d %d %d %f %ld", 
 	     (char *)&hs.name, &hs.color, &hs.winner, 
 	     &hs.loser, &hs.rating, &hs.date);
       highscore[i] = hs;
@@ -850,7 +827,7 @@ void App::writeHighscore() {
     s = QString("Highscore_%1").arg(i);
     HighScore hs = highscore[i];
     e = QString("%1 %2 %3 %4 %5 %6")
-	      .arg(hs.name).arg(hs.color).arg(hs.winner)
+	      .arg(QString::fromUtf8(hs.name)).arg(hs.color).arg(hs.winner)
 	      .arg(hs.loser).arg(hs.rating).arg(hs.date);
     conf->writeEntry(s, e);
   }
@@ -868,7 +845,7 @@ int MAX(int a, int b) {
 
 void App::showHighscore(int focusitem) {
   // this may look a little bit confusing...
-  QDialog *dlg = new QDialog(0, i18n("Hall of Fame"), TRUE);
+  QDialog *dlg = new QDialog(this, "hall_of_fame", TRUE);
   dlg->setCaption(i18n("KReversi: Hall Of Fame"));
 
   QVBoxLayout *tl = new QVBoxLayout(dlg, 10);
@@ -920,7 +897,7 @@ void App::showHighscore(int focusitem) {
   unsigned i, j;
 
   for(i = 0; i < 10; i++) {
-    const char *color = 0;
+    QString color;
     HighScore hs;
     if(i < highscore.size()) {
       hs = highscore[i];
@@ -972,8 +949,8 @@ void App::showHighscore(int focusitem) {
       table->addWidget(e[i][j], i+2, j, AlignCenter);	
     }
     
-  QPushButton *b = new QPushButton(i18n("Close"), dlg);
-  if(style() == MotifStyle)
+  QPushButton *b = new QPushButton(i18n("&Close"), dlg);
+  if(style().guiStyle() == MotifStyle)
     b->setFixedSize(b->sizeHint().width() + 10,
 		    b->sizeHint().height() + 10);
   else
@@ -1015,7 +992,7 @@ QString App::getPlayerName() {
 
   QPushButton *b = new QPushButton(i18n("OK"), dlg);
   b->setDefault(TRUE);
-  if(style() == MotifStyle)
+  if(style().guiStyle() == MotifStyle)
     b->setFixedSize(b->sizeHint().width() + 10,
 		    b->sizeHint().height() +10);
   else
@@ -1048,7 +1025,8 @@ QString App::getPlayerName() {
 }
 
 void App::slotBarChanged() {
-debug("void App::slotBarChanged()");
+  kdDebug() << "void App::slotBarChanged()" << endl;
+
   KConfig *conf = kapp->config();
   if(conf) {
     conf->writeEntry("Toolbar_1_Pos", (int)(tb->barPos()));
