@@ -31,6 +31,10 @@
 #include <kconfig.h>
 #include "HighScore.h"
 #include <kdebug.h>
+#include <ksimpleconfig.h>
+#include <kstddirs.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 
 HighScore::HighScore(QWidget *mainWindow) {
      hs_dlg=0;
@@ -54,7 +58,7 @@ HighScore::showScore(bool forceNew) {
 	  hs_dlg->exec();
 	  return;
      }
-	
+
      hs_dlg=new QDialog(m_mainWindow,"Highscore", true);
 
      ASSERT(hs_dlg);
@@ -96,13 +100,13 @@ HighScore::showScore(bool forceNew) {
 	  l = new QLabel(s, hs_dlg);
 	  l->setMinimumSize(l->sizeHint());
 	  l1->addWidget(l, i, 0);
-	
+
 	  l = new QLabel(hs_dlg);
 	  if(i < hiscore_used)
 	       l->setText(hiscore[i].name);
 	  l->setMinimumSize(l->sizeHint());
 	  l1->addWidget(l, i, 1);
-	
+
 	  s = "";
 	  if(i < hiscore_used)
 	       s.sprintf("%5d", hiscore[i].score);
@@ -197,51 +201,60 @@ HighScore::add(int board, int score,int colors,const QString &name) {
      }
 }
 
+void
+HighScore::loadScore(KConfig *cfg)
+{
+    KConfigGroupSaver cs(cfg, "Highscore");
+
+    hiscore_used=0;
+    for (int i=0;i<HS_MAXENTRY;i++) {
+        QString name;
+        name.sprintf("Rank_%i",i);
+        if (!cfg->hasKey(name)) break;
+        // kdDebug() << "load " << i << endl;
+        QStringList value = cfg->readListEntry(name, ' ');
+        hiscore[i].board = (*value.at(0)).toInt();
+        hiscore[i].score = (*value.at(1)).toInt();
+        hiscore[i].colors = (*value.at(2)).toInt();
+        hiscore[i].name = (*value.at(3));;
+        hiscore_used++;
+    }
+    playername=cfg->readEntry("LastPlayer",i18n("Anonymous"));
+    kdDebug() << "lastplayer: " << playername << endl;
+}
 
 void
 HighScore::loadScore() {
-     QString name, value;
-     KConfig *config = kapp->config();
-
-     config->sync();
-     QString oldgroup=config->group();
-     config->setGroup("Highscore");
-
-     hiscore_used=0;
-     for (int i=0;i<HS_MAXENTRY;i++) {
-	  name.sprintf("Rank_%i",i);
-	  if (!config->hasKey(name)) break;
-	  // kdDebug() << "load " << i << endl;
-	  QStringList value = config->readListEntry(name, ' ');
-	  hiscore[i].board = (*value.at(0)).toInt();
-	  hiscore[i].score = (*value.at(1)).toInt();
-	  hiscore[i].colors = (*value.at(2)).toInt();
-	  hiscore[i].name = (*value.at(3));;
-	  hiscore_used++;
-     }
-     playername=config->readEntry("LastPlayer",i18n("Anonymous"));
-     kdDebug() << "lastplayer: " << playername << endl;
-     config->setGroup(oldgroup);
+    QString file = locateLocal("appdata", "highscore");
+    if (KStandardDirs::exists(file)) {
+        KSimpleConfig config(file);
+        loadScore(&config);
+    } else {
+        loadScore(KGlobal::config());
+    }
 }
 
 void
 HighScore::storeScore() {
-     QString name, value;
-     KConfig *config = kapp->config();
+    QString file = locateLocal("appdata", "highscore");
+    struct stat sst;
+    mode_t mode = S_IRUSR | S_IWUSR;
+    if (!::stat(file.local8Bit(), &sst))
+        mode = sst.st_mode;
 
-     QString oldgroup=config->group();
-     config->setGroup("Highscore");
+    KSimpleConfig *config = new KSimpleConfig(file);
+    config->setGroup("Highscore");
 
-     for (int i=0;i<hiscore_used;i++) {
-	  name = QString::fromLatin1("Rank_%1").arg(i);
-	  value = QString::fromLatin1("%1 %2 %3 %4").
-	          arg(hiscore[i].board).
-		  arg(hiscore[i].score).
-	          arg(hiscore[i].colors).
-		  arg(hiscore[i].name);
-	  config->writeEntry(name, value);
-     }
-     config->writeEntry("LastPlayer",playername);
-     config->setGroup(oldgroup);
-     config->sync();
+    for (int i=0;i<hiscore_used;i++) {
+        QString name = QString::fromLatin1("Rank_%1").arg(i);
+        QString value = QString::fromLatin1("%1 %2 %3 %4").
+                        arg(hiscore[i].board).
+                        arg(hiscore[i].score).
+                        arg(hiscore[i].colors).
+                        arg(hiscore[i].name);
+        config->writeEntry(name, value);
+    }
+    config->writeEntry("LastPlayer",playername);
+    delete config;
+    ::chmod(file.local8Bit(), mode);
 }
