@@ -25,8 +25,7 @@ class Board : public QFrame, public GenericTetris
  Q_OBJECT
 
  public:
-    Board(uint blockWidth, uint blockHeight,
-		  uint width, uint height, bool graphical, GiftPool *,
+    Board(uint width, uint height, bool graphical, GiftPool *,
 		  QWidget *parent, const char *name=0);
 	virtual ~Board();
 
@@ -56,13 +55,15 @@ class Board : public QFrame, public GenericTetris
 	void enableAnimations(bool enabled) { _animations = enabled; }
 
  public slots:
- void pMoveLeft();
+    void pMoveLeft();
     void pMoveRight();
     void pDropDown();
     void pOneLineDown();
     void pRotateLeft();
     void pRotateRight();
 
+	void setBlockSize(uint);
+
  private slots:
     void timeout();
 
@@ -72,6 +73,7 @@ class Board : public QFrame, public GenericTetris
     void updateRemovedSignal(int nbRemoved);
     void updateScoreSignal(int score);
     void updateLevelSignal(int level);
+	void blockSizeChanged();
 
  protected:
 	// standard methods
@@ -106,7 +108,7 @@ class Board : public QFrame, public GenericTetris
 	void _afterRemove(bool first);
 	void startTimer();
 	void showNextPiece(bool show)   { emit showNextPieceSignal(!show); }
-	void showPieceConfig(bool show) { emit showPieceConfigSignal(!show); }
+	void showPieceConfig(bool show) { emit showPieceConfigSignal(show); }
 	void showBoard(bool show);
 	void showCanvas(QCanvas *c, bool show);
 
