@@ -1,6 +1,8 @@
 #ifndef DEFINES_H
 #define DEFINES_H
 
+#include <qglobal.h>
+
 #define LCD_HEIGHT     40
 #define BORDER         10
 #define SEPARATOR      10
@@ -21,4 +23,8 @@
 
 #define LED_SPACING 5
 
+extern const uint MIN_BLOCK_SIZE;
+extern const uint MAX_BLOCK_SIZE;
+extern const bool BLOCK_SIZE_MUST_BE_ODD;
+
 #endif
