@@ -98,21 +98,20 @@ void FEBoard::remove()
 	
     // score calculation from another puyo game
 	// not sure it is the "official" way
-	uint _nbPuyos = rem.size();
-	uint _puyos = 0;
+	uint _nbPuyos = rem.size(); // number of group detroyed
+	uint _puyos = 0;            // number of eggs destroyed
 	for (uint k=0; k<rem.size(); k++) _puyos += rem[k];
 
+	uint bonus = _puyos - 3; // puyos is more than 4 since we are here !
+	if ( _puyos==11  ) bonus += 2;
+	if ( _nbPuyos>=2 ) bonus += 3 * (1 << (_nbPuyos-2)); // 3 * 2^(nb-2)
+	if ( chained>=1  ) bonus += 1 << (chained+2);        // 2^(chained+2)
+	uint dscore = 10 * _nbPuyos * bonus;
+	
+	chained++;
+	giftRest += dscore;
 	nbPuyos += _nbPuyos;
 	updateRemoved(nbRemoved() + _puyos);
-	chained ++;
-
-	uint base  = 10 * _nbPuyos;
-	uint bonus = _puyos - 3;
-	if ( _puyos==11 ) bonus += 2;
-	if ( _nbPuyos>1 ) bonus += 3*(1 << (_nbPuyos-2));
-	if ( chained>1  ) bonus += 1 << (chained+1);
-	uint dscore = base*bonus;
-	giftRest += dscore;
 	updateScore(score() + dscore);
 
 	// update level
