@@ -41,5 +41,5 @@ static const char *FE_DESCRIPTION =
 int main(int argc, char **argv)
 {
 	return generic_main(argc, argv, "kfouleggs", I18N_NOOP("KFoulEggs"),
-						FE_DESCRIPTION, TRUE);
+						FE_DESCRIPTION);
 }
