@@ -14,6 +14,8 @@ Field::Field(QWidget *parent, const char *name)
 	installEventFilter(topLevelWidget());
 
 	board = createBoard(this);
+	connect(this, SIGNAL(setBlockSizeSignal(uint)),
+			board, SLOT(setBlockSize(uint)));
 
 	QGridLayout *top;
 	QVBoxLayout *vbl;
@@ -84,7 +86,6 @@ Field::Field(QWidget *parent, const char *name)
 	top->addWidget(board->giftPool(), 0, 2);
 
     // board
-	board->setFixedSize( board->sizeHint() );
 	connect(board,     SIGNAL(updateScoreSignal(int)),
 			showScore, SLOT(display(int)));
 	connect(board,     SIGNAL(updateRemovedSignal(int)),
@@ -97,7 +98,9 @@ Field::Field(QWidget *parent, const char *name)
 	shadow = new Shadow(board, board->frameWidth(), this);
 	QWhatsThis::add(shadow, i18n("Shadow of the current piece"));
 	connect(board,  SIGNAL(showPieceConfigSignal(bool)),
-			shadow, SLOT(redraw(bool)));
+			shadow, SLOT(reveal(bool)));
+	connect(board, SIGNAL(blockSizeChanged()),
+			shadow, SLOT(blockSizeChanged()));
 	top->addWidget(shadow, 2, 2);
 
 // column 4
@@ -132,6 +135,8 @@ Field::Field(QWidget *parent, const char *name)
 	labShowNext->setAlignment(AlignCenter);
 	vbl->addWidget(labShowNext, 0);
 	showNext = new ShowNextPiece(board->next(), this);
+	connect(board, SIGNAL(blockSizeChanged()),
+			showNext, SLOT(blockSizeChanged()));
 	vbl->addWidget(showNext, 0);
 	vbl->addStretch(4);
 
@@ -190,9 +195,9 @@ void Field::showOpponents(bool show)
 	}
 }
 
-void Field::enablePreference(int type, bool enabled)
+void Field::enablePreference(PreferenceType type, bool enabled)
 {
-	switch ((PreferenceType)type) {
+	switch (type) {
 	case ShowNext:
 		if (enabled) {
 			showNext->show();
