@@ -39,25 +39,42 @@ uint GPieceInfo::maxHeight() const
 }
 
 //-----------------------------------------------------------------------------
-SequenceArray::SequenceArray(uint bw, uint bh)
-: _blockWidth(bw), _blockHeight(bh)
+SequenceArray::SequenceArray()
+: _blockWidth(0), _blockHeight(0)
 {
 	const GPieceInfo *pinfo = Piece::info();
-	resize(pinfo->nbBlockTypes());
+	fill(0, pinfo->nbBlockTypes());
+}
+
+void SequenceArray::setBlockSize(uint bw, uint bh)
+{
+	_blockWidth  = bw;
+	_blockHeight = bh;
+	const GPieceInfo *pinfo = Piece::info();
 	QList<QPixmap> pixmaps;
 	pixmaps.setAutoDelete(TRUE);
 	QList<QPoint> points;
 	points.setAutoDelete(TRUE);
+	uint nm = pinfo->nbBlockModes();
 	for (uint i=0; i<size(); i++) {
 		for (uint k=0; k<2; k++)
-			for (uint j=0; j<pinfo->nbBlockModes(); j++) {
-				points.append(new QPoint(0, 0));
-				pixmaps.append(pinfo->drawPixmap(_blockWidth, _blockHeight,
-												 i, j, k==1));
+			for (uint j=0; j<nm; j++) {
+				QPoint *po = new QPoint(0, 0);
+				QPixmap *pi = pinfo->drawPixmap(bw, bh, i, j, k==1);
+				if ( at(i) ) {
+					at(i)->setImage(k*nm + j, new QCanvasPixmap(*pi, *po));
+					delete po;
+					delete pi;
+				} else {
+					points.append(po);
+					pixmaps.append(pi);
+				}
 			}
-		at(i) = new QCanvasPixmapArray(pixmaps, points);
-		pixmaps.clear();
-		points.clear();
+		if ( at(i)==0 ) {
+			at(i) = new QCanvasPixmapArray(pixmaps, points);
+			pixmaps.clear();
+			points.clear();
+		}
 	}
 }
 
@@ -67,11 +84,10 @@ SequenceArray::~SequenceArray()
 }
 
 //-----------------------------------------------------------------------------
-BlockInfo::BlockInfo(uint w, uint h, const SequenceArray &s)
+BlockInfo::BlockInfo(const SequenceArray &s)
 : _sequences(s)
 {
 	// #### set tuning ??
-	resize(w*s.blockWidth(), h*s.blockHeight());
 	setBackgroundColor(black);
 }
 
