@@ -36,8 +36,9 @@ class GPieceInfo
 class SequenceArray : public QArray<QCanvasPixmapArray *>
 {
  public:
-	SequenceArray(uint blockWidth, uint blockHeight);
+	SequenceArray();
 	~SequenceArray();
+	void setBlockSize(uint width, uint height);
 
 	uint blockWidth() const  { return _blockWidth; }
     uint blockHeight() const { return _blockHeight; }
@@ -50,7 +51,7 @@ class SequenceArray : public QArray<QCanvasPixmapArray *>
 class BlockInfo : public QCanvas
 {
  public:
-	BlockInfo(uint width, uint height, const SequenceArray &);
+	BlockInfo(const SequenceArray &);
 	const SequenceArray &sequences() const { return _sequences; }
 
  private:
