@@ -1,12 +1,11 @@
 #include "inter.h"
 #include "inter.moc"
 
-#include <qmessagebox.h>
 #include <qtimer.h>
+
 #include <klocale.h>
 #include <kapp.h>
 
-#include "field.h"
 #include "dialogs.h"
 #include "version.h"
 #include "defines.h"
@@ -40,9 +39,10 @@ Interface::Interface(KAccel *kacc, QWidget *parent, const char *name)
 MPBoard *Interface::newBoard(uint)
 {
 	Field *f = new Field(this);
-	connect(this, SIGNAL(enablePreference(int, bool)),
-			f, SLOT(enablePreference(int, bool)));
+	connect(this, SIGNAL(enablePreference(Field::PreferenceType, bool)),
+			f, SLOT(enablePreference(Field::PreferenceType, bool)));
 	connect(this, SIGNAL(AIConfigChangedSignal()), f, SLOT(AIConfigChanged()));
+	connect(this, SIGNAL(setBlockSize(uint)), f, SLOT(setBlockSize(uint)));
 	setPreferences();
 	return f;
 }
@@ -59,6 +59,7 @@ void Interface::setPreferences()
 	emit enablePreference(Field::ShowShadow, OptionDialog::readShadow());
 	emit enablePreference(Field::ShowNext, OptionDialog::readShowNext());
 	emit enablePreference(Field::Animations, OptionDialog::readAnimations());
+	emit setBlockSize(OptionDialog::readBlockSize());
 }
 
 void Interface::configureAI()
