@@ -3,6 +3,7 @@
 
 #include "lib/mp_simple_interface.h"
 #include "types.h"
+#include "field.h"
 
 const MPGameInfo &gameInfo();
 
@@ -18,7 +19,8 @@ class Interface : public MPSimpleInterface
 	void configureAI();
 	
  signals:
-	void enablePreference(int type, bool enabled);
+	void enablePreference(Field::PreferenceType, bool enabled);
+	void setBlockSize(uint);
 	void AIConfigChangedSignal();
 	
  private:
