@@ -1,12 +1,12 @@
 #ifndef MAIN_H
 #define MAIN_H
 
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 
 class Interface;
 class GPieceInfo;
 
-class MainWidget : public KTMainWindow
+class MainWidget : public KMainWindow
 {
  Q_OBJECT
 
@@ -30,7 +30,7 @@ class MainWidget : public KTMainWindow
 };
 
 int generic_main(int argc, char **argv, const char *name,
-				 const char *trName, const char *description, bool catalog);
+				 const char *trName, const char *description);
 GPieceInfo *createPieceInfo();
 
 #endif // MAIN_H
