@@ -40,5 +40,5 @@ static const char *TL_DESCRIPTION =
 int main(int argc, char **argv)
 {
 	return generic_main(argc, argv, "ksirtet", I18N_NOOP("KSirtet"),
-						TL_DESCRIPTION, FALSE);
+						TL_DESCRIPTION);
 }
