@@ -24,7 +24,7 @@ this software.
 #ifndef GAMEWINDOW_H
 #define GAMEWINDOW_H
 
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 
 #include "ksmiletris.h"
 
@@ -33,7 +33,7 @@ class QPopupMenu;
 class GameWidget;
 class KStatusBar;
 
-class GameWindow : public KTMainWindow {
+class GameWindow : public KMainWindow {
 	Q_OBJECT
 
 public:
