@@ -102,10 +102,26 @@ void Game::menu()
     list.append("3");
     balls->setItems(list);
 
+	ballsAI = new KSelectAction(i18n("Balls AI"), 0, this, SLOT(ballsAIChecked()),
+			actionCollection(), "opt_ballsai");
+	QStringList bai;
+	bai.append("Default");
+	bai.append("Dumb");
+	bai.append("Killer");
+	ballsAI->setItems(bai);
+	
     snakes = new KSelectAction(i18n("&Snakes"), 0, this, SLOT(snakesChecked()),
 				actionCollection(), "opt_snakes");
     snakes->setItems(list);
 
+	snakesAI = new KSelectAction(i18n("Snakes AI"), 0, this, SLOT(snakesAIChecked()),
+			actionCollection(), "opt_snakesai");
+	QStringList sai;
+	sai.append("Random");
+	sai.append("Eater");
+	sai.append("Killer");
+	snakesAI->setItems(sai);
+	
     new KAction(i18n("Change keys..."),0, this, SLOT(confKeys()),
 		actionCollection(), "opt_change_keys");
     new KAction(i18n("Starting Room..."), 0, this, SLOT(startingRoom()),
@@ -143,6 +159,13 @@ void Game::ballsChecked()
     rattler->setBalls(x);
 }
 
+void Game::ballsAIChecked()
+{
+	int x = ballsAI->currentItem();
+	conf->writeEntry("BallsAI", x);
+	rattler->setBallsAI(x);
+}
+
 void Game::snakesChecked()
 {
     int x = snakes->currentItem();
@@ -150,6 +173,13 @@ void Game::snakesChecked()
     rattler->setCompuSnakes(x);
 }
 
+void Game::snakesAIChecked()
+{
+	int x = snakesAI->currentItem();
+	conf->writeEntry("SnakesAI", x);
+	rattler->setSnakesAI(x);
+}
+
 void Game::skillChecked()
 {
     for ( int x = 0; x < 4; x++)
@@ -174,7 +204,9 @@ void Game::checkMenuItems()
 {
     conf->setGroup("General");
     balls->setCurrentItem(conf->readNumEntry("Balls", 1));
+	ballsAI->setCurrentItem(conf->readNumEntry("BallsAI", 0));
     snakes->setCurrentItem(conf->readNumEntry("ComputerSnakes", 1));
+	snakesAI->setCurrentItem(conf->readNumEntry("SnakesAI", 0));
     int skill = conf->readNumEntry("Skill", 1);
     if (skill < 0 || skill > 3)
 	skill = 1;
@@ -235,7 +267,15 @@ void Game::startingRoom()
 
 void Game::confKeys()
 {
-    Keys *keys = new Keys();
+	Keys *keys = new Keys(0, 0, 1);
+	if (keys->exec() == QDialog::Accepted)
+		rattler->initKeys();
+	delete keys;
+}
+
+void Game::confKeys2()
+{
+	Keys *keys = new Keys(0, 0, 2);
     if (keys->exec() == QDialog::Accepted)
 	rattler->initKeys();
     delete keys;
@@ -279,6 +319,7 @@ int main( int argc, char **argv )
   aboutData.addAuthor("Michel Filippi",0, "mfilippi@sade.rhein-main.de");
   aboutData.addAuthor("Robert Williams");
   aboutData.addAuthor("Andrew Chant",0, "achant@home.com");
+	aboutData.addCredit("Andr Luiz dos Santos", "AI stuff", "andre@netvision.com.br");
   KCmdLineArgs::init( argc, argv, &aboutData );
 
   KApplication a;
