@@ -3,6 +3,7 @@
 
 #include <qfile.h>
 #include <qstring.h>
+#include <qstringlist.h>
 
 #include <qpixmap.h>
 #include <qimage.h>
@@ -17,7 +18,7 @@ public:
     QPixmap getPixmap(int);
     int max();
 private:
-    QList<QString> list;
+    QStringList list;
 };
 
 
