@@ -2,11 +2,11 @@
 #define SCORE_H
 
 #include <qdialog.h>
-#include <qdatetm.h>
+#include <qdatetime.h>
 #include <qwidget.h>
 #include <qlabel.h>
-#include <qgrpbox.h>
-#include <qlined.h>
+#include <qgroupbox.h>
+#include <qlineedit.h>
 #include <qstring.h>
 #include <qfile.h>
 
@@ -16,8 +16,8 @@ class ScoreBox : public QWidget
 public:
     ScoreBox( QWidget *parent=0, const char *name=0, int current = -1);
 
-    void setTitle( const char *);
-    void setScore(int, int, const char *, const char *);
+    void setTitle(const QString &);
+    void setScore(int, int, const QString &, const QString&);
 
 protected:
     void resizeEvent( QResizeEvent * );
@@ -31,6 +31,12 @@ private:
     QLabel *player[5];
 };
 
+typedef struct {
+	QDate date;
+	int  points;
+	QString player;
+} score;
+
 class Score : public QObject
 {
     Q_OBJECT
@@ -42,18 +48,10 @@ public slots:
     void display(int newHall, int newToday = -1);
 
 private:
-
-    struct {
-	QDate date;
-	int  points;
-	char *player;
-    } hall[5], today[5];
-
-
+    score hall[5], today[5];
     void read();
     void write();
 
-    QString formatDate(int, int, int);
     QString getPlayerName();
     QString playerName;
     QFile file;
