@@ -44,10 +44,10 @@ KeySetup::KeySetup(SOptions *opt,QWidget *parent,const char *name)
       button[p][PlayerKeyRight]=new QPushButton(i18n("Rotate Right"),bplayer[p]);
       button[p][PlayerKeyAcc]=new QPushButton(i18n("Accelerate"),bplayer[p]);
       button[p][PlayerKeyShot]=new QPushButton(i18n("Shot"),bplayer[p]);
-      button[p][PlayerKeyMine]=new QPushButton(i18n("Mine"),bplayer[p]);
+      button[p][PlayerKeyMine]=new QPushButton(i18n("Verb","Mine"),bplayer[p]);
       for(i=0;i<PlayerKeyNum;i++)
       {
-         keyName[p][i]=new QLabel(KAccel::keyToString((unsigned)key[p][i]),bplayer[p]);
+         keyName[p][i]=new QLabel(KAccel::keyToString((unsigned)key[p][i],true),bplayer[p]);
          keyName[p][i]->setLineWidth(1);
          keyName[p][i]->setFrameStyle(QFrame::Sunken|QFrame::Panel);
          keyName[p][i]->setMinimumSize( 80, 10 );
@@ -58,7 +58,7 @@ KeySetup::KeySetup(SOptions *opt,QWidget *parent,const char *name)
    for(p=0;p<2;p++)
    {
       grid[p]=new QGridLayout(bplayer[p],PlayerKeyNum+1,2,10);
-      grid[p]->addRowSpacing( 0, spacingHint( ) );
+      grid[p]->addRowSpacing( 0, 2 * spacingHint( ) );
       grid[p]->setRowStretch(0,0);
       for(i=0;i<PlayerKeyNum;i++)
       {
@@ -98,6 +98,7 @@ void KeySetup::setButtons(int pl,int b)
          button[p][i]->setOn((pl==p)&&(b==i));
    waitForKey=b;
    player=pl;
+   grabKeyboard();
 }
 
 void KeySetup::slotDefault()
@@ -116,7 +117,7 @@ void KeySetup::slotDefault()
 
    for(p=0;p<2;p++)
       for(i=0;i<PlayerKeyNum;i++)
-         keyName[p][i]->setText(KAccel::keyToString(key[p][i]));
+         keyName[p][i]->setText(KAccel::keyToString(key[p][i], true));
 }
 
 void KeySetup::slotOk()
@@ -209,13 +210,14 @@ void KeySetup::keyPressEvent(QKeyEvent *ev)
       if(player<2)
       {
          key[player][waitForKey]=ev->key();
-         keyName[player][waitForKey]->setText(KAccel::keyToString(ev->key()));
+         keyName[player][waitForKey]->setText(KAccel::keyToString(ev->key(), true));
       }
       setButtons(-1,-1);
       ev->accept();
    }
    else
       QDialog::keyPressEvent(ev);
+   releaseKeyboard();
 }
 
 #ifdef kspaceduel_only_for_xgettext
@@ -287,14 +289,6 @@ int ConfigSetup::Position[EditNum]=
  0,1,2,3,
  0,1,2,3};
 
-#ifdef kspaceduel_only_for_xgettext
- i18n("General"),i18n("Bullet"),i18n("Mine"),i18n("Ship"),i18n("Sun"),
- i18n("Start"),i18n("Powerups")
-#endif
-
-const char *ConfigSetup::TabName[TabNum]=
-{"General","Bullet","Mine","Ship","Sun","Start","Powerups"};
-
 const int LCDLen=6;
 
 ConfigSetup::ConfigSetup(SConfig *custom,SOptions *opt,
@@ -347,7 +341,7 @@ ConfigSetup::ConfigSetup(SConfig *custom,SOptions *opt,
       configCombo->insertItem(i18n(predefinedConfigName[i]));
    configCombo->insertItem(i18n("Custom"));
 
-   boxlayout->addSpacing(9);
+   boxlayout->addSpacing( 2 * spacingHint() );
    boxlayout->addWidget(configCombo);
    boxlayout->addWidget(tabs);
    
@@ -361,9 +355,14 @@ ConfigSetup::ConfigSetup(SConfig *custom,SOptions *opt,
    for(i=0;i<TabNum;i++)
       stacklayout[i]->activate();
 
-   for(i=0;i<TabNum;i++)
-      tabs->addTab(configWidgets[i],i18n(TabName[i]));
-   
+   tabs->addTab(configWidgets[0],i18n("General"));
+   tabs->addTab(configWidgets[1],i18n("Bullet"));
+   tabs->addTab(configWidgets[2],i18n("Name","Mine"));
+   tabs->addTab(configWidgets[3],i18n("Ship"));
+   tabs->addTab(configWidgets[4],i18n("Sun"));
+   tabs->addTab(configWidgets[5],i18n("Start"));
+   tabs->addTab(configWidgets[6],i18n("Powerups"));
+ 
    configCombo->setCurrentItem(opt->lastConfig);
    if(opt->lastConfig==predefinedConfigNum)
    {
@@ -642,7 +641,7 @@ HitpointSetup::HitpointSetup(SOptions *opt,QWidget *parent,const char *name)
    QLabel *blueLabel=new QLabel(i18n("Blue Player"),box);
 
    QVBoxLayout *boxlayout = new QVBoxLayout( box, spacingHint( ) );
-   boxlayout->addSpacing(spacingHint()/*10*/);
+   boxlayout->addSpacing(2 * spacingHint()/*10*/);
    QGridLayout *grid=new QGridLayout(2,3);
    boxlayout->addLayout(grid);
    
@@ -695,7 +694,7 @@ GraphicSetup::GraphicSetup(SOptions *opt,QWidget *parent,const char *name)
    connect(refreshslider,SIGNAL(valueChanged(int)),refreshnumber,SLOT(display(int)));
    
    QVBoxLayout *boxlayout=new QVBoxLayout(box,spacingHint());
-   boxlayout->addSpacing(spacingHint());
+   boxlayout->addSpacing(2 * spacingHint());
    QGridLayout *partslayout=new QGridLayout(1,3);
    boxlayout->addLayout(partslayout);
    partslayout->addWidget(refreshlabel,0,0);
