@@ -10,13 +10,14 @@
 #include "defines.h"
 
 MyTopLevelWidget::MyTopLevelWidget(const char* name)
-      :KTMainWindow(name)
+      :KMainWindow(0, name)
 {
+   setCaption("");
    wview = new DuelWidget( this );
    initActions( );
    initStatusBar( );
 
-   setView(wview);
+   setCentralWidget(wview);
 
    readConfig(kapp->config());
 }
@@ -25,15 +26,16 @@ void MyTopLevelWidget::initActions( )
 {
    KToggleAction* newAct;
    
-   KStdAction::quit( this, SLOT( quit( ) ), actionCollection( ) );
+   ( void )new KAction( i18n( "&Quit" ), "exit", CTRL + Key_Q, this,
+                        SLOT( quit( ) ), actionCollection( ), "game_quit" );
 
-   ( void )new KAction( i18n( "New &Game" ), "newgame", 
+   ( void )new KAction( i18n( "New &Game" ), "spnewgame", 
                         CTRL + Key_G, wview, SLOT( newGame( ) ),
                         actionCollection( ), "new_game" );
-   ( void )new KAction( i18n( "&New Round" ), "newround",
+   ( void )new KAction( i18n( "&New Round" ), "spnewround",
                         CTRL + Key_N, wview, SLOT( newRound( ) ),
                         actionCollection( ), "new_round" );
-   newAct = new KToggleAction( i18n( "&Pause" ), "pausegame", 
+   newAct = new KToggleAction( i18n( "&Pause" ), "sppausegame", 
                                CTRL + Key_P, wview, SLOT( togglePause( ) ),
                                actionCollection( ), "pause" );
    newAct->setChecked( false );
@@ -55,9 +57,9 @@ void MyTopLevelWidget::initActions( )
    ( void )new KAction( i18n( "&Ai..." ), 0, wview,
                         SLOT( aiSetup( ) ),
                         actionCollection( ), "options_ai" );
-   KStdAction::showToolbar( this, SLOT( showToolBar( ) ),
+   toolbarAct = KStdAction::showToolbar( this, SLOT( showToolBar( ) ),
                             actionCollection( ) );
-   KStdAction::showStatusbar( this, SLOT( showStatusBar( ) ),
+   statusbarAct = KStdAction::showStatusbar( this, SLOT( showStatusBar( ) ),
                               actionCollection( ) );
 
    KStdAction::saveOptions( this, SLOT( saveOptions( ) ),
@@ -69,11 +71,12 @@ void MyTopLevelWidget::initActions( )
 
 void MyTopLevelWidget::initStatusBar( )
 {
-   statusBar( )->insertItem(i18n(" paused "),IDS_PAUSE);
-   statusBar( )->insertItem("   ",IDS_MAIN);
+   statusBar( )->insertItem(i18n(" paused "),IDS_PAUSE,1);
+   statusBar( )->insertItem("   ",IDS_MAIN,1);
+   statusBar( )->insertItem("",42,2);
 
-   QObject::connect(wview,SIGNAL(setStatusText(const char*,int)),
-                    SLOT(setStatusText(const char*,int)));
+   QObject::connect(wview,SIGNAL(setStatusText(const QString &,int)),
+                    SLOT(setStatusText(const QString &,int)));
 
 }
 
@@ -83,7 +86,7 @@ void MyTopLevelWidget::start()
    wview->newRound();
 }
 
-void MyTopLevelWidget::setStatusText(const char* str,int id)
+void MyTopLevelWidget::setStatusText(const QString & str,int id)
 {
    statusBar( )->changeItem(str,id);
 }
@@ -123,20 +126,22 @@ void MyTopLevelWidget::keySetup()
 
 void MyTopLevelWidget::showToolBar( )
 {
-   if( toolBar( )->isVisible( ) )
-      toolBar( )->hide( );
+   if( toolbarAct->isChecked() )
+      toolBar()->show( );
    else
-      toolBar( )->show( );
+      toolBar()->hide( );
 }
 
 void MyTopLevelWidget::showStatusBar( )
 {
-   if( statusBar( )->isVisible( ) )
-      statusBar( )->hide( );
-   else
+   if( statusbarAct->isChecked() )
       statusBar( )->show( );
+   else
+      statusBar( )->hide( );
 }
 
 MyTopLevelWidget::~MyTopLevelWidget( )
 {
 }
+
+#include "topwidget.moc"
