@@ -37,14 +37,14 @@
 #include <kmessagebox.h>
 #include <kaction.h>
 #include <kstdaction.h>
-
+#include <kapp.h>
 
 #define ID_STATUS_BASE 40
 
 #define MESSAGE_TIME 2000
 
 KTron::KTron(const char *name)
-      : KTMainWindow(name),
+      : KMainWindow(0, name),
        skillAction(3)
 {
    playerPoints[0]=playerPoints[1]=0;
@@ -54,7 +54,7 @@ KTron::KTron(const char *name)
 
    tron=new Tron(this);
    connect(tron,SIGNAL(gameEnds(Player)),SLOT(changeStatus(Player)));
-   setView(tron);
+   setCentralWidget(tron);
 
    // create statusbar
    KStatusBar *statusbar= statusBar();
@@ -183,16 +183,16 @@ KTron::KTron(const char *name)
    int height=config->readNumEntry("Height",300);
    resize(width,height);
 
-
    config->setGroup("Game");
    bool status=config->readBoolEntry("Computerplayer1",true);
    toggleAction=(KToggleAction *)actionCollection()->action("computer_player1");
    toggleAction->setChecked(status);
-
+   tron->setComputerplayer(One,status);
+   
    status=config->readBoolEntry("Computerplayer2",false);
    toggleAction=(KToggleAction *)actionCollection()->action("computer_player2");
    toggleAction->setChecked(status);
-
+   tron->setComputerplayer(Two,status);
 
    QString temp="";
    playerName[0]=config->readEntry("Name_Pl1",temp);
@@ -206,10 +206,12 @@ KTron::KTron(const char *name)
 
    Skill skill=(Skill)config->readNumEntry("Skill",(int)Medium);
    skillAction[skill]->setChecked(true);
+   tron->setSkill(skill);
 
    selectAction=(KSelectAction*)actionCollection()->action("select_velocity");
    int velocity=config->readNumEntry("Velocity",5);
    selectAction->setCurrentItem(velocity-1);
+   tron->setVelocity(velocity);
 
 
    selectAction=(KSelectAction*)actionCollection()->action("select_style");
@@ -226,6 +228,7 @@ KTron::KTron(const char *name)
    }
    config->setGroup("Game");
    selectAction->setCurrentItem(newStyle);
+   tron->setStyle(newStyle);
 
    int size=config->readNumEntry("RectSize",10);
    selectAction=(KSelectAction*)actionCollection()->action("select_size");
@@ -247,6 +250,7 @@ KTron::KTron(const char *name)
          selectAction->setCurrentItem(4);
          break;
    }
+   tron->setRectSize(size);
 
    tron->enableWinnerColor(config->readBoolEntry("ChangeWinnerColor",true));
    tron->setAcceleratorBlocked(config->readBoolEntry("AcceleratorBlocked",false));
@@ -259,7 +263,7 @@ KTron::KTron(const char *name)
 
 KTron::~KTron()
 {
-   saveSettings();
+	saveSettings();
 }
 
 
@@ -446,6 +450,7 @@ void KTron::showWinner(Player winner)
 
 void KTron::quit()
 {
+   saveSettings();
    kapp->quit();
 }
 
@@ -735,3 +740,4 @@ void KTron::saveProperties(KConfig *config)
   config->writeEntry("BackgroundImage",bgPixURL.url());
 }
 
+#include "ktron.moc"
